import { Component, OnInit } from '@angular/core';
import {ApiService} from '../../service/api';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {ActivatedRoute, Router} from '@angular/router';
import {fadeIn} from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-sensor-detail',
  templateUrl: './sensor-detail.component.html',
  styleUrls: ['./sensor-detail.component.scss'],
  animations: [fadeIn]
})
export class SensorDetailComponent implements OnInit {

  isLoading = false;
  deviceData = [];
  deviceNo = '';
  name = '';
  req: any = {};
  req2: any = {};
  req3 = {};
  req5: any = {};
  isUC = false;
  isUC2 = false;
  isMC = false;
  isUpdate = false;
  probsModels = [];
  topicModels = [];
  actualData = [];
  wayData = [];
  selectTime3 = 24;
  isClose = false;
  constructor(private api: ApiService, private message: NzMessageService, private router: Router,
              private ac: ActivatedRoute, private modalService: NzModalService, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.ac.queryParams.subscribe((e) => {
      if (e.deviceNo) {
        this.deviceNo = e.deviceNo;
        this.name = e.name;
        this.getTopicData();
        this.getProbsModels();
        this.getTopicModels();
        this.getProbs();
        this.getCurrent();
      }
    });
  }

  next = (data) => {
    if (data && data.code === 1) {
      this.message.success(data && data.message ? data.message : '操作成功');
      this.cancel();
      this.getTopicData();
      this.getProbsModels();
      this.getTopicModels();
      this.getProbs();
      this.getCurrent();
    } else if (data && data.code === 0) {
      this.message.error(data && data.message ? data.message : '操作失败');
    } else {
      this.message.error(data && data.message ? data.message : '获取数据失败');
    }
  }

  getProbsModels() {
    this.isLoading = true;
    this.api.probesModel.getAll(['', (data) => {
      if (data && data.constructor === Array) {
        this.probsModels = data;
      } else {
        this.message.error(data && data.message ? data.message : '获取数据失败');
      }
      this.isLoading = false;
    }]);
  }

  getTopicData() {
    this.isLoading = true;
    this.api.topic.getByDeviceNo([{deviceNo: this.deviceNo}, (data) => {
      if (data && data.constructor === Array) {
        this.deviceData = data;
      } else {
        this.message.error(data && data.message ? data.message : '获取数据失败');
      }
      this.isLoading = false;
    }]);
  }

  getTopicModels() {
    this.isLoading = true;
    this.api.topicModel.getAll(['', (data) => {
      if (data && data.constructor === Array) {
        this.topicModels = data;
      } else {
        this.message.error(data && data.message ? data.message : '获取数据失败');
      }
      this.isLoading = false;
    }]);
  }

  getProbs() {
    this.isLoading = true;
    this.api.probes.getProbesByGateway([{deviceNo: this.deviceNo}, (data) => {
      if (data && data.constructor === Array) {
        this.wayData = data;
      } else {
        this.message.error(data && data.message ? data.message : '获取数据失败');
      }
      this.isLoading = false;
    }]);
  }

  getCurrent() {
    this.isLoading = true;
    this.api.data.getRealData([{deviceNo: this.deviceNo}, (data) => {
      if (data && data.constructor === Array) {
        this.actualData = data;
      } else {
        this.message.error(data && data.message ? data.message : '获取数据失败');
      }
      this.isLoading = false;
    }]);
  }

  toDetail(one) {
    this.router.navigate(['/app/deviceCenter/sensorMgr/sensorDetail/sensorTopicWay'],
      {queryParams: {deviceNo: one.deviceNo, topicName: one.topicName}});
  }

  onSearch() {}

  close() {}

  changeModel() {
    this.isMC = true;
    this.req5 = {
      deviceNo: this.deviceNo
    };
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.req.deviceNo = this.deviceNo;
    this.isUC = true;
  }

  update(one) {
    this.req = {...one};
    this.isUpdate = true;
    this.req.oldTopicName = one.topicName;
    this.isUC = true;
  }

  cancel() {
    this.isUC = false;
    this.isMC = false;
    this.isUC2 = false;
  }

  save() {
    this.isLoading = true;
    if (this.isUC && this.isUpdate) {
      this.api.topic.updateTopic([this.req, this.next]);
    } else if (this.isUC && !this.isUpdate) {
      this.api.topic.addTopic([this.req, this.next]);
    } else if (this.isMC) {
      this.api.device.deploySensor([this.req5, this.next]);
    } else if (this.isUC2 && this.isUpdate) {
      this.req2.deviceNo = this.deviceNo;
      this.api.probes.updateProbes([this.req2, this.next]);
    } else if (this.isUC2 && !this.isUpdate) {
      this.req2.deviceNo = this.deviceNo;
      this.api.probes.addProbes([this.req2, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    this.api.topic.delTopic([{deviceNo: one.deviceNo, topicName: one.topicName}, this.next]);
  }


  add2() {
    this.isUpdate = false;
    this.req2 = {};
    this.req2.deviceNo = this.deviceNo;
    this.isUC2 = true;
  }

  update2(one) {
    this.req2 = {...one};
    this.req2.type = one.pType;
    this.isUpdate = true;
    this.req2.oldName = one.name;
    this.isUC2 = true;
  }

  deleteConfirm2(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete2(one)
    });
  }

  delete2(one) {
    this.isLoading = true;
    this.api.probes.delAProbes([{deviceNo: one.deviceNo, topicName: one.topicName, name: one.name}, this.next]);
  }

  toSee() {}
}
