import { Component, OnInit } from '@angular/core';
import {ApiService} from '../../service/api';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {ActivatedRoute, Router} from '@angular/router';
import {TranslateService} from '@ngx-translate/core';
import {fadeIn} from '../../animation/fade-in';

@Component({
  selector: 'app-sensor-topic-way',
  templateUrl: './sensor-topic-way.component.html',
  styles: [],
  animations: [fadeIn]
})
export class SensorTopicWayComponent implements OnInit {

  req: any = {};
  data = [];
  isLoading = false;
  deviceNo = '';
  topicName = '';
  isV = false;
  isUpdate = false;

  constructor(private api: ApiService, private message: NzMessageService, private ac: ActivatedRoute,
              private translate: TranslateService, private router: Router, private modalService: NzModalService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.ac.queryParams.subscribe((params) => {
      if (params.deviceNo) {
        this.deviceNo = params.deviceNo;
        this.topicName = params.topicName;
        this.getData();
      }
    });
  }

  getData() {
    this.isLoading = true;
    this.api.probes.getAll([{deviceNo: this.deviceNo, topicName: this.topicName}, this.next]);
  }

  next = (data) => {
    if (data && data.constructor === Array) {
      this.data = data;
    } else if (data && data.code === 1) {
      this.message.success(data.message ? data.message : '操作成功');
      this.isV = false;
      this.getData();
    } else if (data && data.code === 0) {
      this.message.error(data.message ? data.message : '操作失败');
    } else {
      this.message.error(data && data.message ? data.message : '获取数据失败');
    }
    this.isLoading = false;
  }

  add() {
    this.req = {};
    this.isUpdate = false;
    this.isV = true;
  }

  update(one) {
    this.isUpdate = true;
    this.req = {...one};
    this.req.oldName = one.name;
    this.isV = true;
  }

  cancel() {
    this.isV = false;
  }

  save() {
    this.isLoading = true;
    this.req.deviceNo = this.deviceNo;
    this.req.topicName = this.topicName;
    if (this.isUpdate) {
      this.api.probes.updateProbes([this.req, this.next]);
    } else {
      this.api.probes.addProbes([this.req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    this.api.probes.delAProbes([{deviceNo: this.deviceNo, name: one.name, topicName: this.topicName}, this.next]);
  }
}
